<section name="poll">
    <div class="col-md-12">
        <h1 class="page-header">{{ poll.question }}</h1>
    </div>
    <div class="row">
        <div class="col-md-9">
            <h3>Results</h3>
            {% if poll.get_result %}
                {% include 'feedme/chart.html' %}
            {% endif %}
        </div>
        <div class="col-md-3">
            <div class="row">
            {% if restaurants %}
                <h3>Restaurants</h3>
                {% for restaurant in restaurants %}
                    <p>{{ restaurant }} <a href="{{ restaurant.menu_url }}" target="_blank">menu <span class="glyphicon glyphicon-new-window"></span></a></p>
                {% endfor %}
            {% endif %}
            <hr>
            {% if answer and user.is_authenticated %}
                <form action="" method="POST">
                    {% csrf_token %}
                    <input type="text" name="act" value="vote" hidden>
                    {% for field in answer %}
                        {{ field }}
                    {% endfor %}
                    <input type="submit" value="Vote" class="btn btn-primary btn-sm">
                </form>
            {% endif %}
            </div>
        </div>
    </div>
</section>
