{% if messages %}
<div class="row">
    <div class="col-md-12">
    <div class="container-fluid messages">
        <div class="row-fluid">
            <div class="span12">
                {% for message in messages %}
                    <div class="alert alert-{{ message.tags }}" data-alert>
                        <button type="button" class="close" data-dismiss="alert">&times;</button>
                        <p>{{ message }}</p>
                    </div>
                {% endfor %}
            </div>
        </div>
    </div>
    </div>
</div>
{% endif %}
