<nav class="subnavbar">
  <div class="container">
      <ul id="feedme-menu">
        {% if group %}
          <li class="top-menu-link"><a href="{% url "feedme:feedme_index_new" group %}">Feedme:{{ group }}</a></li>
          <li><a class="top-menu-link" href="#{# url "feedme:feedme_order_history" #}">{{ user.username }}: {{ user.balance.get_balance_string }}</a></li>
        {% endif %}
        {% for group in feedme_groups %}
          <li>
            <a class="top-menu-link" href="{% url 'feedme:feedme_index_new' group %}">{{ group }}</a>
          </li>
            {% if is_admin %}
                <li>
                    <a href="{% url 'feedme:admin' group %}"><span class="glyphicon glyphicon-cog"></span></a>
                </li>
            {% endif %}
        {% endfor %}
        {% if not user.is_authenticated %}
          <li class="pull-right">
            <form method="post" action="" hidden>
              {% csrf_token %}
              <input type="text" name="act" value="log_in" hidden>
              <input type="text" name="username" placeholder="Username">
              <input type="password" name="password" placeholder="********">
              <input type="submit" name="log_in" value="Log in">
            </form>
          </li>
        {% endif %}
      </ul>
  </div>
</nav>
